OC.L10N.register(
    "federatedfilesharing",
    {
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "გსურთ დაამატოთ {owner}@{remote}-ის დისტანცური გაზიარება {name}?",
    "Remote share" : "დისტანციური გაზიარება",
    "Remote share password" : "დისტანციური გაზიარების პაროლი",
    "Cancel" : "გაუქმება",
    "Add remote share" : "დისტანციური გაზიარების დამატება",
    "Invalid Federated Cloud ID" : "არასწორი ფედერალური ქლაუდ ID",
    "Server to server sharing is not enabled on this server" : "ამ სერვერზე სერვერიდან სერვერზე გაზიარება არაა ჩართული",
    "Couldn't establish a federated share." : "ფედერალური გაზიარება ვერ დამყარდა.",
    "Couldn't establish a federated share, maybe the password was wrong." : "ფედერალური გაზიარება ვერ დამყარდა, შეისაძლოა პაროლი არ იყოს მართებული.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "ფედერალური გაზიარების მოთხოვნა გაიგზავნა, თქვენ მიიღებთ მოწვევას. შეამოწმეთ თქვენი შეტყობინებები.",
    "Not allowed to create a federated share with the same user" : "იმავე მომხმარებელთან ფედერალური გაზიარება ვერ შეიქმნება",
    "File is already shared with %s" : "ფაილი უკვე გაზიარებულია მომხმარებელთან %s ",
    "Could not find share" : "გაზიარება ვერ იქნა ნაპოვნი",
    "Federated sharing" : "ფედერალური გაზიარება",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "თქვენ მიიღეთ გაზიარება {share} როგორც დისტანციური გაზიარება მომხმარებლისგან {user} (სახელით {behalf})",
    "You received {share} as a remote share from {user}" : "თქვენ მიიღეთ {share} როგორც დისტანციური გაზიარება მომხმარებლისგან {user}",
    "Accept" : "მიღება",
    "Decline" : "უარყოფა",
    "Federated Cloud Sharing" : "ფედერალური ქლაუდ გაზიარება",
    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "გააზიარეთ ჩემთან ჩემი #Nextcloud-ის ფედერალური ქლაუდ ID-ის მეშვეობით, იხილეთ %s",
    "Share with me through my #Nextcloud Federated Cloud ID" : "გააზიარეთ ჩემთან ჩემი #Nextcloud-ის ფედერალური ქლაუდ ID-ის მეშვეობით",
    "Sharing" : "გაზიარება",
    "Federated file sharing" : "ფედერალური ფაილების გაზიარება",
    "Allow users on this server to receive shares from other servers" : "დართეთ ნება მომხმარებლებს ამ სერვერზე მიიღონ გაზიარებები სხვა სერვერებიდან",
    "Search global and public address book for users" : "მოძებნეთ გლობალური და ღია მომხმარებლების მისამართების წიგნები",
    "Allow users to publish their data to a global and public address book" : "დართეთ ნება მომხმარებლებს გამოაქყვეყნონ მათი მონაცემები გლობალურ და საზოგადო მისამართების წიგნებში",
    "Federated Cloud" : "ფედერალური ქლაუდი",
    "Your Federated Cloud ID:" : "თქვენი ფედერალური ქლაუდ ID:",
    "Share it so your friends can share files with you:" : "გააზიარეთ, რომ თქვენმა მეგობრებმაც შეძლონ ფაილების გაზიარება თქვენთან:",
    "Twitter" : "Twitter-ი",
    "Add to your website" : "საიტზე დამატება",
    "Share with me via Nextcloud" : "გამიზიარე Nextcloud-ის მეშვეობით",
    "HTML Code:" : "HTML კოდი:",
    "Copy to clipboard" : "კოპირება ბუფერში",
    "Copy" : "კოპირება",
    "Copied!" : "კოპირებულია!",
    "Not supported!" : "არაა მხარდაჭერილი!",
    "Press ⌘-C to copy." : "კოპირებისთვის დააჭირეთ ⌘-C.",
    "Press Ctrl-C to copy." : "კოპირებისთვის დააჭირეთ Ctrl-C-ს.",
    "Open documentation" : "ღია დოკუმენტაცია",
    "Adjust how people can share between servers." : "განაგეთ თუ როგორ შეუძლიათ ადამიანებს სერვერებს შორის მოახდინონ გაზიარება."
},
"nplurals=2; plural=(n!=1);");
